<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetFacepile.php
 * 
 * This class provides methods for the Facepile widget
 */
class WordpressConnectWidgetFacepile extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetFacepile
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetFacepile() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-facepile', 
			'description' => 'Wordpress Connect Facepile Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-facepile', 'WPC Facepile Widget', $widget_ops );		
		
	}

	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $width, $max_rows ){
			
		echo "\n" . '<!-- Wordpress Connect Facepile Widget v',WPC_VERSION,'-->' , "\n";
		
		echo '<fb:facepile width="',$width,'" max-rows="',$max_rows,'"></fb:facepile>';
			
		echo "\n" . '<!-- Wordpress Connect Facepile Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
		$width = $instance['width'];
		$max_rows = $instance['max_rows'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}
 
		WordpressConnectWidgetFacepile::printWidget(
			$width, 
			$max_rows
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = $new_instance['title'];
		$instance['width'] = $new_instance['width'];
		$instance['max_rows'] = $new_instance['max_rows'];
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_FACEPILE_NAME,
			'width' => 200,
			'max_rows' => 1
		);
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'max_rows' ); ?>">Num Rows: <acronym title="The maximum number of rows of profile pictures to show.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'max_rows' ); ?>" size="8" value="<?php echo $instance['max_rows']; ?>" />
		</p>
		
<?php
	}
}


?>