<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetLikeBox.php
 * 
 * This class provides methods for the Like Box widget
 */
class WordpressConnectWidgetLikeBox extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetLikeBox
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetLikeBox() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-like-box', 
			'description' => 'Wordpress Connect Like Box Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-like-box', 'WPC Like Box Widget', $widget_ops );		
		
	}

	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $type, $id, $width, $height, $connections, $stream = 'true', $header = 'true' ){
			
		echo "\n" . '<!-- Wordpress Connect Like Box Widget v',WPC_VERSION,' -->' , "\n";
		
		if ( $type == WPC_TYPE_IFRAME ){
			
			echo '<iframe src="http://www.facebook.com/plugins/likebox.php?id=',$id,'&amp;width=',$width,'&amp;connections=',$connections,'&amp;stream=',$stream,'&amp;header=',$header,'&amp;height=',$height,'" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:',$width,'px; height:',($height + 40),'px;" allowTransparency="true"></iframe>';
			
		}
		else if ( $type == WPC_TYPE_XFBML ){
			
			echo '<fb:like-box profile_id="',$id,'" width="',$width,'" connections="',$connections,'" stream="',$stream,'" header="',$header,'"></fb:like-box>';
			
		}
			
		echo "\n" . '<!-- Wordpress Connect Like Box Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
		$type = $instance['type'];
		$id = $instance['id'];
		$width = $instance['width'];
		$height = $instance['height'];
		$connections = $instance['connections'];
		$stream = $instance['stream'];
		$header = $instance['header'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}

		WordpressConnectWidgetLikeBox::printWidget(
			$type,
			$id, 
			$width,
			$height,
			$connections,
			( $stream ) ? 'true' : 'false',
			( $header ) ? 'true' : 'false'
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = trim( $new_instance['title'] );
		$instance['type'] = trim( $new_instance['type'] );
		$instance['id'] = trim( $new_instance['id'] );
		$instance['width'] = trim( $new_instance['width'] );
		$instance['height'] = trim( $new_instance['height'] );
		$instance['connections'] = trim( $new_instance['connections'] );
		$instance['stream'] = isset( $new_instance['stream'] );
		$instance['header'] = isset( $new_instance['header'] );
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_LIKE_BOX_NAME,
			'type' => WPC_TYPE_XFBML,
			'id' => '',
			'width' => 200,
			'height' => 320,
			'connections' => '8', 
			'stream' => TRUE,
			'header' => TRUE
		);
		
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>">Type: <acronym title="The rendering type of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" >
				<option <?php echo ( $instance['type'] == WPC_TYPE_IFRAME ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_IFRAME; ?>"><?php echo WPC_TYPE_IFRAME; ?></option>
				<option <?php echo ( $instance['type'] == WPC_TYPE_XFBML ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_XFBML; ?>"><?php echo WPC_TYPE_XFBML;?></option>
			</select> 
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'id' ); ?>">Facebook Page ID: <acronym title="The ID of the Facebook Page for this Like box.">(?)</acronym></label>
			<input type="text" id="<?php echo $this->get_field_id( 'id' ); ?>" name="<?php echo $this->get_field_name( 'id' ); ?>"  value="<?php echo $instance['id']; ?>"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>">Height: <acronym title="The height of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'height' ); ?>" size="8" value="<?php echo $instance['height']; ?> "/> (iframe only)
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'connections' ); ?>">Connections: <acronym title="Show a sample of this many users who have liked this Page.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'connections' ); ?>" size="8" value="<?php echo $instance['connections']; ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'stream' ); ?>">Stream: <acronym title="Show the profile stream for the public profile.">(?)</acronym></label>
			<input type="checkbox" <?php echo ( $instance['stream'] === TRUE ) ? 'checked="checked"' : ''; ?> id="<?php echo $this->get_field_id( 'stream' ); ?>" name="<?php echo $this->get_field_name( 'stream' ); ?>" /> Show stream
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'header' ); ?>">Header: <acronym title="Show the 'Find us on Facebook' bar at top. Only shown when either stream or connections are present.">(?)</acronym></label>
			<input type="checkbox" <?php echo ( $instance['header'] === TRUE ) ? 'checked="checked"' : ''; ?> id="<?php echo $this->get_field_id( 'header' ); ?>" name="<?php echo $this->get_field_name( 'header' ); ?>" /> Show Header
		</p>						
		
<?php
	}
}


?>