<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetLiveStream.php
 * 
 * This class provides methods for the Live Stream widget
 */
class WordpressConnectWidgetLiveStream extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetLiveStream
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetLiveStream() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-live-stream', 
			'description' => 'Wordpress Connect Live Stream Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-live-stream', 'WPC Live Stream Widget', $widget_ops );		
		
	}


	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $type, $id, $width, $height, $xid = '' ){
			
		echo "\n" . '<!-- Wordpress Connect Live Stream Widget v',WPC_VERSION,'-->' , "\n";
		
		if ( $type == WPC_TYPE_IFRAME ){
			
			echo '<iframe src="http://www.facebook.com/plugins/livefeed.php?app_id=',$id,'&amp;width=',$width,'&amp;height=',$height,'&amp;xid=',$xid,'" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:',$width,'px; height:',$height,'px;" allowTransparency="true"></iframe>';
		}
		else if ( $type == WPC_TYPE_XFBML ){
			
			echo '<fb:live-stream event_app_id="',$id,'" width="',$width,'" height="',$height,'" xid="',$xid,'"></fb:live-stream>';
			
		}
			
		echo "\n" . '<!-- Wordpress Connect Live Stream Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
		$type = $instance['type'];
		$id = $instance['id'];
		$width = $instance['width'];
		$height = $instance['height'];
		$xid = $instance['xid'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}

		WordpressConnectWidgetLiveStream::printWidget(
			$type,
			$id, 
			$width,
			$height,
			$xid
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = trim( $new_instance['title'] );
		$instance['type'] = trim( $new_instance['type'] );
		$instance['width'] = trim( $new_instance['width'] );
		$instance['height'] = trim( $new_instance['height'] );
		$instance['xid'] = trim( $new_instance['xid'] );
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_LIVE_STREAM_NAME,
			'type' => WPC_TYPE_XFBML,
			'id' => '',
			'width' => 240,
			'height' => 320,
			'xid' => '' 
		);
		
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>">Type: <acronym title="The rendering type of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" >
				<option <?php echo ( $instance['type'] == WPC_TYPE_IFRAME ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_IFRAME; ?>"><?php echo WPC_TYPE_IFRAME; ?></option>
				<option <?php echo ( $instance['type'] == WPC_TYPE_XFBML ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_XFBML; ?>"><?php echo WPC_TYPE_XFBML;?></option>
			</select> 
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>">Height: <acronym title="The height of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'height' ); ?>" size="8" value="<?php echo $instance['height']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'xid' ); ?>">XID: <acronym title="If you have multiple live stream boxes on the same page, specify a unique `xid` for each.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'xid' ); ?>" size="8" value="<?php echo $instance['xid']; ?>" />
		</p>
		
<?php
	}
}


?>