<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetLogin.php
 * 
 * This class provides methods for the Login (with Faces) widget
 */
class WordpressConnectWidgetLogin extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetLogin
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetLogin() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-login', 
			'description' => 'Wordpress Connect Login Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-login', 'WPC Login Widget', $widget_ops );		
		
	}

	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $show_faces, $width, $max_rows ){
			
		echo "\n" . '<!-- Wordpress Connect Login Widget v',WPC_VERSION,'-->' , "\n";
		
		echo '<fb:login-button show-faces="',$show_faces,'"  width="',$width,'" max-rows="',$max_rows,'"></fb:login-button>';
			
		echo "\n" . '<!-- Wordpress Connect Login Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
		$show_faces = $instance['show_faces'];
		$width = $instance['width'];
		$max_rows = $instance['max_rows'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}

		WordpressConnectWidgetLogin::printWidget(
			( $show_faces ) ? 'true' : 'false',
			$width, 
			$max_rows
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = trim( $new_instance['title'] );
		$instance['show_faces'] = isset( $new_instance['show_faces'] );
		$instance['width'] = trim( $new_instance['width'] );
		$instance['max_rows'] = trim( $new_instance['max_rows'] );
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_LOGIN_NAME,
			'show_faces' => TRUE,
			'width' => 200,
			'max_rows' => 1
		);
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_faces' ); ?>">Show Faces: <acronym title="Show profile pictures below the button.">(?)</acronym></label>
			<input type="checkbox" <?php echo ( $instance['show_faces'] === TRUE ) ? 'checked="checked"' : ''; ?> id="<?php echo $this->get_field_id( 'show_faces' ); ?>" name="<?php echo $this->get_field_name( 'show_faces' ); ?>" /> Show faces
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'max_rows' ); ?>">Num Rows: <acronym title="The maximum number of rows of profile pictures to show.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'max_rows' ); ?>" size="8" value="<?php echo $instance['max_rows']; ?>" />
		</p>
		
<?php
	}
}


?>